=============================
inforcehub
=============================

.. image:: https://badge.fury.io/py/inforcehub.png
    :target: http://badge.fury.io/py/inforcehub

.. image:: https://travis-ci.org/ttamg/inforcehub.png?branch=master
    :target: https://travis-ci.org/ttamg/inforcehub

Utilities for data science and customer management


Features
--------

* helloworld function to test installation ``inforcehub.helloworld()``

